leaftools.split_leaf_at_prolated_duration_and_rest_right_half
=============================================================

.. autofunction:: abjad.tools.leaftools.split_leaf_at_prolated_duration_and_rest_right_half.split_leaf_at_prolated_duration_and_rest_right_half
